@@ -3,10 +3,10 @@ package # hide from PAUSE
 
 use warnings;
 use strict;
-use base 'DBIx::Class::Storage::Statistics';
+use base qw/ DBIx::Class::Storage::Statistics /;
 use Time::HiRes qw/ tv_interval gettimeofday /;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub new {
     my ( $pkg, %args ) = @_;
@@ -17,19 +17,19 @@ sub new {
 sub txn_begin {
     my $self = shift;
 
-    $self->{log}->debug( "BEGIN WORK\n" );
+    $self->{log}->debug("BEGIN WORK\n");
 }
 
 sub txn_rollback {
     my $self = shift;
 
-    $self->{log}->debug( "ROLLBACK\n" );
+    $self->{log}->debug("ROLLBACK\n");
 }
 
 sub txn_commit {
     my $self = shift;
 
-    $self->{log}->debug( "COMMIT\n" );
+    $self->{log}->debug("COMMIT\n");
 }
 
 sub query_start {
@@ -37,16 +37,14 @@ sub query_start {
     my $sql  = shift;
     my @args = @_;
 
-    my $bind = @args ? join ', ', @args : '';
-#    $sql =~ s/FROM/\nFROM/g;
-#    $sql =~ s/,/,\n    /g;
-#    $sql =~ s/JOIN/\nJOIN/g;
-#    $sql =~ s/WHERE/\nWHERE/g;
-#    my $message = "Executing \n $sql : $bind\n";
-    my $message = "Executing \n$sql\n";
-    $message .= "Bind Values : ( $bind )\n";
+    my $count = $self->{_count} ? $self->{_count} + 1 : 1;
+    $self->{_count} = $count;
+
+    my $bind_values = @args ? join ', ', @args : '';
+    my $message = "SQL [$count]\n$sql\n";
+    $message .= "Bind Values : ( $bind_values )\n";
     $self->{log}->debug( $message );
-    $self->{start_time} = [gettimeofday];
+    $self->{start_time} = [ gettimeofday ];
 }
 
 sub query_end {
@@ -54,7 +52,7 @@ sub query_end {
     my $sql  = shift;
     my @args = @_;
 
-    my $message = "-->Query Time : ".tv_interval( $self->{start_time} )."\n";
+    my $message = "-->Query Time : " . tv_interval( $self->{start_time}, [ gettimeofday ] ) . "\n";
     $self->{log}->debug( $message );
     $self->{start_time} = undef;
 }
